@@ -24,8 +24,6 @@
 App Handler
 """
 
-from __future__ import unicode_literals, absolute_import
-
 import os
 # import re
 import datetime
@@ -37,7 +35,6 @@ import tempfile
 import warnings
 import logging
 
-import six
 import humanize
 from mako.template import Template
 
@@ -160,7 +157,7 @@ class AppHandler(object):
         and all values it contains will be coerced.
         """
         if isinstance(value, dict):
-            for key, val in six.iteritems(value):
+            for key, val in value.items():
                 value[key] = self.json_friendly(val)
 
         elif isinstance(value, list):
@@ -171,7 +168,7 @@ class AppHandler(object):
             value = float(value)
 
         elif isinstance(value, datetime.datetime):
-            value = six.text_type(value)
+            value = str(value)
 
         return value
 
@@ -265,6 +262,8 @@ class AppHandler(object):
 
         :returns: Next value as integer.
         """
+        import sqlalchemy as sa
+
         dialect = session.bind.url.get_dialect().name
         if dialect != 'postgresql':
             log.debug("non-postgresql database detected; will use workaround")
@@ -274,7 +273,7 @@ class AppHandler(object):
 
         # normal (uses postgresql sequence)
         sql = "select nextval('{}_seq')".format(key)
-        value = session.execute(sql).scalar()
+        value = session.execute(sa.text(sql)).scalar()
         return value
 
     def get_setting(self, session, name, typ=None, **kwargs):
@@ -293,7 +292,7 @@ class AppHandler(object):
            depending on the ``typ`` param.
         """
         model = self.model
-        setting = session.query(model.Setting).get(name)
+        setting = session.get(model.Setting, name)
         value = None if setting is None else setting.value
 
         if typ == 'utctime':
@@ -357,7 +356,7 @@ class AppHandler(object):
         # create or update the setting
         setting = None
         if not force_create:
-            setting = session.query(model.Setting).get(name)
+            setting = session.get(model.Setting, name)
         if not setting:
             setting = model.Setting(name=name)
             session.add(setting)
@@ -375,7 +374,7 @@ class AppHandler(object):
         :param name: Name of the setting to delete.
         """
         model = self.model
-        setting = session.query(model.Setting).get(name)
+        setting = session.get(model.Setting, name)
         if setting:
             session.delete(setting)
 
@@ -741,13 +740,13 @@ class AppHandler(object):
 
         # organize registered classes by spec
         specs = {}
-        for Handler in six.itervalues(Handlers):
+        for Handler in Handlers.values():
             spec = '{}:{}'.format(Handler.__module__, Handler.__name__)
             specs[spec] = Handler
 
         # many handlers may not be registered per se, but may be
         # designated via config.  so try to include those too
-        for Handler in six.itervalues(Handlers):
+        for Handler in Handlers.values():
             spec = self.get_designated_import_handler_spec(Handler.get_key())
             if spec and spec not in specs:
                 specs[spec] = load_object(spec)
@@ -807,7 +806,7 @@ class AppHandler(object):
                 return group[0]
 
         designated = []
-        for key, group in six.iteritems(grouped):
+        for key, group in grouped.items():
             Handler = find_designated(key, group)
             if Handler:
                 # nb. we must instantiate here b/c otherwise if we
@@ -1514,7 +1513,7 @@ class AppHandler(object):
 
         # this seems like a sane fallback..?
         if fallback is NOTSET:
-            return six.text_type(value)
+            return str(value)
 
         # but if fallback specified, use that
         return fallback
