@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2022 Lance Edgar
+#  Copyright © 2010-2023 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -65,7 +65,7 @@ class BatchHandler(object):
     execute_with_versioning = True
     delete_with_versioning = True
 
-    def __init__(self, config):
+    def __init__(self, config, **kwargs):
         self.config = config
         self.app = self.config.get_app()
         self.enum = config.get_enum()
@@ -744,6 +744,7 @@ class BatchHandler(object):
         # record the execution kwargs within batch params, if there
         # were any.  this is mostly for troubleshooting after the fact
         if kwargs:
+            kwargs = self.get_executed_with_kwargs(batch, **kwargs)
             try:
                 # first make sure kwargs are JSON-safe
                 json.dumps(kwargs)
@@ -756,6 +757,16 @@ class BatchHandler(object):
 
         return result
 
+    def get_executed_with_kwargs(self, batch, **kwargs):
+        """
+        Should return a JSON-safe set of kwargs the batch was executed
+        with, for saving into the batch params.
+
+        If there are any "special" kwargs, they may need to be
+        type-coerced or perhaps simply removed.
+        """
+        return kwargs
+
     def get_effective_rows(self, batch):
         """
         Should return the set of rows from the given batch which are
@@ -865,6 +876,14 @@ class BatchHandler(object):
             # rows being deleted
             del batch.data_rows[:]
 
+    def get_filepath(self, batch, **kwargs):
+        """
+        Get the absolute path of a particular file associated with the
+        given batch.
+        """
+        # TODO: probably need to rework this somehow..
+        return batch.filepath(self.config, **kwargs)
+
     def delete_extra_data(self, batch, progress=None, **kwargs):
         """
         Delete all "extra" data for the batch.  This method should *not* bother
