@@ -24,8 +24,6 @@
 Console Commands
 """
 
-from __future__ import unicode_literals, absolute_import
-
 import os
 import sys
 import json
@@ -39,7 +37,6 @@ import warnings
 import logging
 from getpass import getpass
 
-import six
 import humanize
 
 from rattail import __version__
@@ -117,7 +114,6 @@ def list_argument(string):
     return parse_list(string)
 
 
-@six.python_2_unicode_compatible
 class Command(Object):
     """
     The primary command for the application.
@@ -533,7 +529,8 @@ class CheckDatabase(Subcommand):
         import sqlalchemy as sa
 
         try:
-            self.config.rattail_engine.execute("select version()")
+            with self.config.rattail_engine.begin() as cxn:
+                cxn.execute(sa.text("select version()"))
         except sa.exc.OperationalError as e:
             self.stderr.write("\nfailed to connect to DB!\n\n{}\n".format(e))
             sys.exit(1)
@@ -926,7 +923,7 @@ class MakeConfig(Subcommand):
         templates = self.app.get_all_config_templates()
         self.stdout.write("CONFIG TEMPLATES:\n")
         self.stdout.write("=========================\n")
-        for name, path in six.iteritems(templates):
+        for name, path in templates.items():
             self.stdout.write("{:25s} {}\n".format(name, path))
         self.stdout.write("=========================\n")
 
@@ -1156,8 +1153,7 @@ class RunAndMail(Subcommand):
             retcode = error.returncode
             log.warning("command exited with code: %s", retcode)
 
-        if six.PY3:
-            output = output.decode(errors='replace')
+        output = output.decode(errors='replace')
 
         run_ended = make_utc()
         runtime = run_ended - run_began
@@ -1215,20 +1211,21 @@ class RunSQL(Subcommand):
         sql = ' '.join(sql)
         engine = sa.create_engine(args.engine)
 
-        result = engine.execute(sql)
-        rows = result.fetchall()
-        if rows:
-            table = texttable.Texttable(max_width=args.max_width)
+        with engine.begin() as cxn:
+            result = cxn.execute(sa.text(sql))
+            rows = result.fetchall()
+            if rows:
+                table = texttable.Texttable(max_width=args.max_width)
 
-            # force all columns to be treated as text.  that seems a bit
-            # heavy-handed but is definitely the simplest way to deal with
-            # issues such as a UPC being displayed in scientific notation
-            table.set_cols_dtype(['t' for col in rows[0]])
+                # force all columns to be treated as text.  that seems a bit
+                # heavy-handed but is definitely the simplest way to deal with
+                # issues such as a UPC being displayed in scientific notation
+                table.set_cols_dtype(['t' for col in rows[0]])
 
-            # add a header row, plus all data rows
-            table.add_rows([rows[0].keys()] + rows)
+                # add a header row, plus all data rows
+                table.add_rows([rows[0].keys()] + rows)
 
-            self.stdout.write("{}\n".format(table.draw()))
+                self.stdout.write("{}\n".format(table.draw()))
 
 
 class Upgrade(Subcommand):
