@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2022 Lance Edgar
+#  Copyright © 2010-2023 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -24,12 +24,8 @@
 DataSync Consumers
 """
 
-from __future__ import unicode_literals, absolute_import
-
 import warnings
 
-import six
-
 from rattail import importing
 from rattail.db import Session
 from rattail.config import parse_list
@@ -85,7 +81,7 @@ class DataSyncConsumer(object):
             session.set_continuum_user(self.runas_username)
 
         # update all importers with current Rattail session
-        for importer in six.itervalues(self.importers):
+        for importer in self.importers.values():
             importer.session = session
             importer.datasync_setup()
 
@@ -355,8 +351,7 @@ class FromRattailConsumer(DataSyncImportConsumer):
 
     def get_host_object(self, session, change):
         model = self.model
-        return session.query(getattr(model, change.payload_type))\
-                      .get(change.payload_key)
+        return session.get(getattr(model, change.payload_type), change.payload_key)
 
 
 class NullTestConsumer(DataSyncConsumer):
