@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2021 Lance Edgar
+#  Copyright © 2010-2023 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -24,8 +24,6 @@
 Models for customer order batches
 """
 
-from __future__ import unicode_literals, absolute_import
-
 import sqlalchemy as sa
 from sqlalchemy import orm
 from sqlalchemy.ext.declarative import declared_attr
@@ -68,6 +66,7 @@ class CustomerOrderBatch(BatchMixin, CustomerOrderBase, Base):
         backref=orm.backref(
             'batches',
             order_by='CustomerOrderBatch.id',
+            cascade_backrefs=False,
             doc="""
             List of batches associated with the customer order.
             """))
