@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2022 Lance Edgar
+#  Copyright © 2010-2023 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -24,8 +24,6 @@
 Data model for label batches
 """
 
-from __future__ import unicode_literals, absolute_import
-
 import sqlalchemy as sa
 from sqlalchemy import orm
 from sqlalchemy.ext.declarative import declared_attr
@@ -65,6 +63,7 @@ class LabelBatch(BatchMixin, Base):
         backref=orm.backref(
             'label_batch',
             uselist=False,
+            cascade_backrefs=False,
             doc="""
             Reference to the label batch to which this handheld batch was converted.
             """))
@@ -117,6 +116,7 @@ class LabelBatchFromHandheld(Base):
             collection_class=ordering_list('ordinal', count_from=1),
             order_by=ordinal,
             cascade='all, delete-orphan',
+            cascade_backrefs=False,
             doc="""
             Sequence of raw label / handheld batch associations.
             """))
@@ -131,6 +131,7 @@ class LabelBatchFromHandheld(Base):
             '_label_batch',
             uselist=False,
             cascade='all, delete-orphan',
+            cascade_backrefs=False,
             doc="""
             Indirect reference to the label batch to which this handheld batch was converted.
             """))
@@ -185,7 +186,10 @@ class LabelBatchRow(ProductBatchRowMixin, Base):
         doc="""
         Reference to the :class:`LabelProfile` with which the row is associated.
         """,
-        backref=orm.backref('_print_labels_rows', cascade='all'))
+        backref=orm.backref(
+            '_print_labels_rows',
+            cascade='all',
+            cascade_backrefs=False))
 
     label_quantity = sa.Column(sa.Integer(), nullable=False, default=1, doc="""
     Number of labels to print for this row/product.
