@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2022 Lance Edgar
+#  Copyright © 2010-2023 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -24,9 +24,6 @@
 Models for purchase order batches
 """
 
-from __future__ import unicode_literals, absolute_import
-
-import six
 import sqlalchemy as sa
 from sqlalchemy import orm
 from sqlalchemy.ext.declarative import declared_attr
@@ -81,6 +78,7 @@ class PurchaseBatch(BatchMixin, PurchaseBase, Base):
         backref=orm.backref(
             'batches',
             order_by='PurchaseBatch.id',
+            cascade_backrefs=False,
             doc="""
             List of batches associated with the purchase.
             """))
@@ -155,6 +153,7 @@ class PurchaseBatch(BatchMixin, PurchaseBase, Base):
         backref=orm.backref(
             'truck_dump_children',
             order_by='PurchaseBatch.id',
+            cascade_backrefs=False,
             doc="""
             List of batches which are "children" of the current batch, which is
             assumed to be a truck dump.
@@ -312,6 +311,7 @@ class PurchaseBatchRowClaim(Base):
         backref=orm.backref(
             'truck_dump_claims',
             cascade='all, delete-orphan',
+            cascade_backrefs=False,
             doc="""
             List of claims which this "child" row makes against rows within a
             truck dump batch.
@@ -327,6 +327,7 @@ class PurchaseBatchRowClaim(Base):
         backref=orm.backref(
             'claims',
             cascade='all, delete-orphan',
+            cascade_backrefs=False,
             doc="""
             List of claims made by "child" rows against this truck dump batch row.
             """))
@@ -405,6 +406,7 @@ class PurchaseBatchCredit(PurchaseCreditBase, Base):
         backref=orm.backref(
             'credits',
             cascade='all, delete-orphan',
+            cascade_backrefs=False,
             doc="""
             List of :class:`PurchaseBatchCredit` instances for the row.
             """))
