@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2021 Lance Edgar
+#  Copyright © 2010-2023 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -24,10 +24,8 @@
 Models for vendor invoice batches
 """
 
-from __future__ import unicode_literals, absolute_import
-
 import sqlalchemy as sa
-from sqlalchemy.orm import relationship
+from sqlalchemy import orm
 from sqlalchemy.ext.declarative import declared_attr
 
 from rattail.db.model import Base, Vendor, FileBatchMixin, ProductBatchRowMixin
@@ -57,7 +55,7 @@ class VendorInvoiceBatch(FileBatchMixin, Base):
 
     vendor_uuid = sa.Column(sa.String(length=32), nullable=False)
 
-    vendor = relationship(Vendor, doc="""
+    vendor = orm.relationship(Vendor, doc="""
     Reference to the :class:`Vendor` to which the invoice pertains.
     """)
 
@@ -115,18 +113,26 @@ class VendorInvoiceBatchRow(ProductBatchRowMixin, Base):
     Number of cases of the product which were originally ordered from the vendor.
     """)
 
+    cases_ordered = orm.synonym('ordered_cases')
+
     ordered_units = sa.Column(sa.Numeric(precision=9, scale=4), nullable=True, doc="""
     Number of units of the product which were originally ordered from the vendor.
     """)
 
+    units_ordered = orm.synonym('ordered_units')
+
     shipped_cases = sa.Column(sa.Numeric(precision=9, scale=4), nullable=True, doc="""
     Number of cases of the product which were shipped by the vendor.
     """)
 
+    cases_shipped = orm.synonym('shipped_cases')
+
     shipped_units = sa.Column(sa.Numeric(precision=9, scale=4), nullable=True, doc="""
     Number of units of the product which were shipped by the vendor.
     """)
 
+    units_shipped = orm.synonym('shipped_units')
+
     out_of_stock = sa.Column(sa.Boolean(), nullable=True, doc="""
     Flag indicating whether the item was known to be "out of stock" per the
     vendor invoice.
