@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2022 Lance Edgar
+#  Copyright © 2010-2023 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -24,11 +24,8 @@
 Data Models for Customers
 """
 
-from __future__ import unicode_literals, absolute_import
-
 import datetime
 
-import six
 import sqlalchemy as sa
 from sqlalchemy import orm
 from sqlalchemy.ext.associationproxy import association_proxy
@@ -86,14 +83,8 @@ class Customer(ContactMixin, Base):
     """)
 
     def __str__(self):
-        if six.PY2:
-            return unicode(self).encode('utf8')
         return self.name or ""
 
-    if six.PY2:
-        def __unicode__(self):
-            return self.name or ""
-
     def add_email_address(self, address, type='Home'):
         email = CustomerEmailAddress(address=address, type=type)
         self.emails.append(email)
@@ -254,12 +245,12 @@ class CustomerNote(Note):
             foreign_keys='CustomerNote.parent_uuid',
             order_by='CustomerNote.created',
             cascade='all, delete-orphan',
+            cascade_backrefs=False,
             doc="""
             Sequence of notes which belong to the customer.
             """))
 
 
-@six.python_2_unicode_compatible
 class CustomerGroup(Base):
     """
     Represents an arbitrary group to which customers may belong.
@@ -295,7 +286,8 @@ class CustomerGroupAssignment(Base):
         CustomerGroup,
         backref=orm.backref(
             '_customers',
-            cascade='all, delete-orphan'))
+            cascade='all, delete-orphan',
+            cascade_backrefs=False))
 
 
 Customer._groups = orm.relationship(
@@ -421,10 +413,4 @@ class PendingCustomer(Base):
     """)
 
     def __str__(self):
-        if six.PY2:
-            return (self.display_name or "").encode('utf_8')
         return self.display_name or ""
-
-    if six.PY2:
-        def __unicode__(self):
-            return self.display_name or ""
