@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2021 Lance Edgar
+#  Copyright © 2010-2023 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -24,11 +24,8 @@
 Data Models for Customer Orders
 """
 
-from __future__ import unicode_literals, absolute_import
-
 import datetime
 
-import six
 import sqlalchemy as sa
 from sqlalchemy import orm
 from sqlalchemy.ext.orderinglist import ordering_list
@@ -123,7 +120,6 @@ class CustomerOrderBase(object):
     """)
 
 
-@six.python_2_unicode_compatible
 class CustomerOrder(CustomerOrderBase, Base):
     """
     Represents an order placed by the customer.
@@ -171,7 +167,6 @@ class CustomerOrder(CustomerOrderBase, Base):
         return "(pending)"
 
 
-@six.python_2_unicode_compatible
 class CustomerOrderItemBase(object):
     """
     Base class for customer order line items.
@@ -407,7 +402,8 @@ class CustomerOrderItemEvent(Base):
         backref=orm.backref(
             'events',
             order_by='CustomerOrderItemEvent.occurred',
-            cascade='all, delete-orphan'))
+            cascade='all, delete-orphan',
+            cascade_backrefs=False))
 
     type_code = sa.Column(sa.Integer, nullable=False)
 
@@ -445,6 +441,7 @@ CustomerOrderItem.notes = orm.relationship(
     """,
     backref=orm.backref(
         'person',
+        cascade_backrefs=False,
         doc="""
         Reference to the order item to which the note is attached.
         """))
