@@ -213,12 +213,18 @@ class EmployeeStore(Base):
 
     employee = orm.relationship(
         Employee,
-        backref=orm.backref('_stores', cascade='all, delete-orphan'))
+        backref=orm.backref(
+            '_stores',
+            cascade='all, delete-orphan',
+            cascade_backrefs=False))
 
     store = orm.relationship(
         Store,
         order_by=Store.name,
-        backref=orm.backref('_employees', cascade='all, delete-orphan'))
+        backref=orm.backref(
+            '_employees',
+            cascade='all, delete-orphan',
+            cascade_backrefs=False))
 
 Employee.stores = association_proxy(
     '_stores', 'store',
@@ -248,12 +254,18 @@ class EmployeeDepartment(Base):
 
     employee = orm.relationship(
         Employee,
-        backref=orm.backref('_departments', cascade='all, delete-orphan'))
+        backref=orm.backref(
+            '_departments',
+            cascade='all, delete-orphan',
+            cascade_backrefs=False))
 
     department = orm.relationship(
         Department,
         order_by=Department.name,
-        backref=orm.backref('_employees', cascade='all, delete-orphan'))
+        backref=orm.backref(
+            '_employees',
+            cascade='all, delete-orphan',
+            cascade_backrefs=False))
 
 Employee.departments = association_proxy(
     '_departments', 'department',
@@ -286,6 +298,7 @@ class EmployeeHistory(Base):
         backref=orm.backref(
             'history',
             order_by='EmployeeHistory.start_date',
+            cascade_backrefs=False,
             doc="""
             Sequence of history records for the employee.
             """))
