@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2020 Lance Edgar
+#  Copyright © 2010-2023 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -24,9 +24,6 @@
 Data Models for Members
 """
 
-from __future__ import unicode_literals, absolute_import
-
-import six
 import sqlalchemy as sa
 from sqlalchemy import orm
 from sqlalchemy.ext.orderinglist import ordering_list
@@ -69,6 +66,7 @@ class Member(ContactMixin, Base):
         """,
         backref=orm.backref(
             'members',
+            cascade_backrefs=False,
             doc="""
             Sequence of member records with which this person is associated.
             """),
@@ -82,6 +80,7 @@ class Member(ContactMixin, Base):
         """,
         backref=orm.backref(
             'members',
+            cascade_backrefs=False,
             doc="""
             Sequence of member records with which this customer is associated.
             """),
@@ -126,14 +125,8 @@ class Member(ContactMixin, Base):
     """)
 
     def __str__(self):
-        if six.PY2:
-            return unicode(self).encode('utf_8')
         return str(self.person or self.customer or "")
 
-    if six.PY2:
-        def __unicode__(self):
-            return unicode(self.person or self.customer or "")
-
     # TODO: deprecate / remove this
     def add_email_address(self, address, type='Home'):
         email = MemberEmailAddress(address=address, type=type)
