@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2022 Lance Edgar
+#  Copyright © 2010-2023 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -24,12 +24,9 @@
 Data Models for Products
 """
 
-from __future__ import unicode_literals, absolute_import
-
 import datetime
 import logging
 
-import six
 import sqlalchemy as sa
 from sqlalchemy import orm
 from sqlalchemy.ext.orderinglist import ordering_list
@@ -47,7 +44,6 @@ from rattail.util import pretty_quantity
 log = logging.getLogger(__name__)
 
 
-@six.python_2_unicode_compatible
 class UnitOfMeasure(Base):
     """
     Maps a UOM abbreviation used by the organization, to the proper UOM code
@@ -105,17 +101,9 @@ class Brand(Base):
     """)
 
     def __str__(self):
-        text = self.name or ''
-        if six.PY2:
-            return text.encode('utf8')
-        return text
-
-    if six.PY2:
-        def __unicode__(self):
-            return self.name or ''
+        return self.name or ''
 
 
-@six.python_2_unicode_compatible
 class Tax(Base):
     """
     Represents a sales tax rate to be applied to products.
@@ -267,6 +255,7 @@ class Product(Base):
         """,
         backref=orm.backref(
             'packs',
+            cascade_backrefs=False,
             doc="""
             List of products which reference the current product as their unit.
             """))
@@ -392,11 +381,15 @@ class Product(Base):
     subdepartment = orm.relationship(
         Subdepartment,
         order_by=Subdepartment.name,
-        backref=orm.backref('products'))
+        backref=orm.backref(
+            'products',
+            cascade_backrefs=False))
 
     category = orm.relationship(
         Category,
-        backref=orm.backref('products'))
+        backref=orm.backref(
+            'products',
+            cascade_backrefs=False))
 
     brand = orm.relationship(
         Brand,
@@ -405,6 +398,7 @@ class Product(Base):
         """,
         backref=orm.backref(
             'products',
+            cascade_backrefs=False,
             doc="""
             List of products for the brand.
             """))
@@ -417,6 +411,7 @@ class Product(Base):
         """,
         backref=orm.backref(
             'products',
+            cascade_backrefs=False,
             doc="""
             List of :class:`Product` objects which belong to this family.
             """))
@@ -429,19 +424,14 @@ class Product(Base):
         """,
         backref=orm.backref(
             'products',
+            cascade_backrefs=False,
             doc="""
             List of :class:`Product` objects which associate with this report code.
             """))
 
     def __str__(self):
-        if six.PY2:
-            return self.full_description.encode('utf8')
         return self.full_description
 
-    if six.PY2:
-        def __unicode__(self):
-            return self.full_description
-
     @property
     def full_description(self):
         """
@@ -552,6 +542,7 @@ class ProductImage(Base):
         backref=orm.backref(
             'image',
             uselist=False,
+            cascade_backrefs=False,
             doc="""
             Reference to the product's image, if any.
             """))
@@ -559,7 +550,6 @@ class ProductImage(Base):
     bytes = sa.Column(sa.LargeBinary(), nullable=False)
 
 
-@six.python_2_unicode_compatible
 class ProductCode(Base):
     """
     Represents an arbitrary "code" for a product.
@@ -681,7 +671,10 @@ class ProductCost(Base):
 
     vendor = orm.relationship(
         Vendor,
-        backref=orm.backref('product_costs', cascade='all'))
+        backref=orm.backref(
+            'product_costs',
+            cascade='all',
+            cascade_backrefs=False))
 
 
 Product.costs = orm.relationship(
@@ -738,7 +731,9 @@ class ProductFutureCost(Base):
         will be applied (when the time comes), if applicable.  If this is
         ``None``, then a new "current" cost record would be created instead.
         """,
-        backref=orm.backref('futures'))
+        backref=orm.backref(
+            'futures',
+            cascade_backrefs=False))
 
     product_uuid = sa.Column(sa.String(length=32), nullable=False)
     product = orm.relationship(
@@ -748,6 +743,7 @@ class ProductFutureCost(Base):
         """,
         backref=orm.backref(
             'future_costs',
+            cascade_backrefs=False,
             doc="""
             Sequence of future cost records for the product, i.e. which have
             yet to become "current" costs.
@@ -761,6 +757,7 @@ class ProductFutureCost(Base):
         """,
         backref=orm.backref(
             'future_costs',
+            cascade_backrefs=False,
             doc="""
             Sequence of future cost records for the vendor, i.e. which have yet
             to become "current" costs.
@@ -888,6 +885,7 @@ class ProductInventory(Base):
             'inventory',
             uselist=False,
             cascade='all, delete-orphan',
+            cascade_backrefs=False,
             doc="""
             Inventory data for the product, if any.
             """))
@@ -923,6 +921,7 @@ class ProductStoreInfo(Base):
             'store_infos',
             collection_class=attribute_mapped_collection('store_uuid'),
             cascade='all, delete-orphan',
+            cascade_backrefs=False,
             doc="""
             List of store-specific info records for the product.
             """))
@@ -969,6 +968,7 @@ class ProductVolatile(Base):
             'volatile',
             uselist=False,
             cascade='all, delete-orphan',
+            cascade_backrefs=False,
             doc="""
             "Volatile" data record for the product, if any.
             """))
@@ -1057,16 +1057,9 @@ class PendingProduct(Base):
                                      self.size)
 
     def __str__(self):
-        if six.PY2:
-            return self.full_description.encode('utf8')
         return self.full_description
 
-    if six.PY2:
-        def __unicode__(self):
-            return self.full_description
 
-
-@six.python_2_unicode_compatible
 class InventoryAdjustmentReason(Base):
     """
     Reasons for adjusting product inventory.
