@@ -24,11 +24,8 @@
 Data model for purchase orders
 """
 
-from __future__ import unicode_literals, absolute_import
-
 import datetime
 
-import six
 import sqlalchemy as sa
 from sqlalchemy import orm
 from sqlalchemy.ext.declarative import declared_attr
@@ -38,7 +35,6 @@ from rattail.db.types import GPCType
 from rattail.util import pretty_quantity
 
 
-@six.python_2_unicode_compatible
 class PurchaseBase(object):
     """
     Base class for purchases; defines common fields.
@@ -321,7 +317,6 @@ class PurchaseItemBase(object):
     """)
 
 
-@six.python_2_unicode_compatible
 class PurchaseCreditBase(object):
     """
     Base class for purchase credits.
@@ -584,6 +579,7 @@ class PurchaseItem(PurchaseItemBase, Base):
         backref=orm.backref(
             'items',
             cascade='all',
+            cascade_backrefs=False,
             doc="""
             List of :class:`PurchaseItem` instances for the purchase.
             """))
@@ -618,6 +614,7 @@ class PurchaseCredit(PurchaseCreditBase, Base):
         """,
         backref=orm.backref(
             'credits',
+            cascade_backrefs=False,
             doc="""
             List of :class:`PurchaseCredit` instances for the purchase.
             """))
