@@ -176,7 +176,8 @@ class VendorContact(Base):
         Person,
         backref=orm.backref(
             '_vendor_contacts',
-            cascade='all, delete-orphan'))
+            cascade='all, delete-orphan',
+            cascade_backrefs=False))
 
     def __str__(self):
         return str(self.person)
