@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2022 Lance Edgar
+#  Copyright © 2010-2023 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -24,15 +24,12 @@
 Label Printing
 """
 
-from __future__ import unicode_literals, absolute_import
-
+import io
 import os
 import os.path
 import socket
 import shutil
 
-import six
-
 from rattail.app import GenericHandler
 from rattail.core import Object
 from rattail.files import temp_path
@@ -55,21 +52,15 @@ class LabelHandler(GenericHandler):
 
         :returns: A :class:`~rattail.labels.LabelFormatter` instance.
         """
-        if not hasattr(self, 'label_formatters'):
-            self.label_formatters = {}
-
         if not profile.formatter_spec:
             if ignore_errors:
                 return
             raise ValueError("label profile has no formatter_spec: {}".format(
                 profile))
 
-        if profile.uuid not in self.label_formatters:
-            factory = self.app.load_object(profile.formatter_spec)
-            formatter = factory(self.config, template=profile.format)
-            self.label_formatters[profile.uuid] = formatter
-
-        return self.label_formatters[profile.uuid]
+        factory = self.app.load_object(profile.formatter_spec)
+        formatter = factory(self.config, template=profile.format)
+        return formatter
 
     def get_printer(self, profile, ignore_errors=False):
         """
@@ -80,33 +71,26 @@ class LabelHandler(GenericHandler):
 
         :returns: A :class:`~rattail.labels.LabelPrinter` instance.
         """
-        if not hasattr(self, 'label_printers'):
-            self.label_printers = {}
-
         if not profile.printer_spec:
             if ignore_errors:
                 return
             raise ValueError("label profile has no printer_spec: {}".format(
                 profile))
 
-        if profile.uuid not in self.label_printers:
+        # create the printer
+        factory = self.app.load_object(profile.printer_spec)
+        printer = factory(self.config)
 
-            # create the printer
-            factory = self.app.load_object(profile.printer_spec)
-            printer = factory(self.config)
+        # establish settings for it
+        for name in printer.required_settings:
+            value = self.get_printer_setting(profile, name)
+            setattr(printer, name, value)
 
-            # establish settings for it
-            for name in printer.required_settings:
-                value = self.get_printer_setting(profile, name)
-                setattr(printer, name, value)
+        # give it a formatter
+        printer.formatter = self.get_formatter(profile,
+                                               ignore_errors=ignore_errors)
 
-            # give it a formatter
-            printer.formatter = self.get_formatter(profile,
-                                                   ignore_errors=ignore_errors)
-
-            self.label_printers[profile.uuid] = printer
-
-        return self.label_printers[profile.uuid]
+        return printer
 
     def get_printer_setting(self, profile, name):
         """
@@ -332,7 +316,7 @@ class CommandNetworkPrinter(CommandPrinter):
         if not self.port:
             raise LabelPrintingError("Printer does not have a port defined.")
 
-        data = six.StringIO()
+        data = io.StringIO()
 
         header = self.batch_header_commands()
         if header:
@@ -492,7 +476,7 @@ class CommandFormatter(LabelFormatter):
         :returns: Unicode string containing the formatted label data,
            i.e. commands to print the labels.
         """
-        fmt = six.StringIO()
+        fmt = io.StringIO()
 
         def format_label(record, i):
             data, quantity = record
@@ -506,10 +490,7 @@ class CommandFormatter(LabelFormatter):
                     fmt.write(header.encode('utf_8'))
                 data = self.get_all_data(data)
                 body = "{}\n".format('\n'.join(self.label_body_commands(product, data)))
-                if six.PY3:
-                    fmt.write(body)
-                else: # PY2
-                    fmt.write(body.encode('utf_8'))
+                fmt.write(body)
                 footer = self.label_footer_commands()
                 if footer:
                     footer = "{0}\n".format('\n'.join(footer))
@@ -518,10 +499,7 @@ class CommandFormatter(LabelFormatter):
         self.app.progress_loop(format_label, labels, progress,
                                message="Formatting labels")
 
-        if six.PY3:
-            val = fmt.getvalue()
-        else: # PY2
-            val = fmt.getvalue().decode('utf_8')
+        val = fmt.getvalue()
         fmt.close()
         return val
 
@@ -613,7 +591,7 @@ class TwoUpCommandFormatter(CommandFormatter):
 
     def format_labels(self, labels, progress=None, **kwargs):
         ""                      # avoid auto-generated docs
-        fmt = six.StringIO()
+        fmt = io.StringIO()
         self.half_started = False
 
         def format_label(record, i):
