@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2022 Lance Edgar
+#  Copyright © 2010-2023 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -24,8 +24,6 @@
 Mail Monitor Daemon
 """
 
-from __future__ import unicode_literals, absolute_import
-
 import re
 import time
 import imaplib
@@ -33,8 +31,6 @@ import imaplib
 import logging
 # from traceback import format_exception
 
-import six
-
 from rattail.daemon import Daemon
 from rattail.mailmon.config import load_mailmon_profiles
 from rattail.mailmon.util import (get_lastrun,
@@ -62,7 +58,7 @@ class MailMonitorDaemon(Daemon):
         monitored = load_mailmon_profiles(self.config)
 
         # loop thru all accounts
-        for key, account in six.iteritems(monitored['__accounts__']):
+        for key, account in monitored['__accounts__'].items():
 
             # fire up the account watcher thread
             watcher = IMAPAccountWatcher(self.config, account)
